<?php

namespace cn\com\maiyoule\mqttclient\test;

use cn\com\maiyoule\mqttclient\biz\AppUserCreateRequest;
use cn\com\maiyoule\mqttclient\biz\AppUserDeleteRequest;
use cn\com\maiyoule\mqttclient\biz\AppUserUpdateRequest;
use cn\com\maiyoule\mqttclient\exception\ApiException;
use cn\com\maiyoule\mqttclient\MQTTManager;
use PHPUnit\Framework\Assert;
use PHPUnit\Framework\TestCase;

class AppManagerTest extends TestCase
{
    private MQTTManager $manager;

    protected function setUp(): void
    {
        $this->manager = new MQTTManager();
        $this->manager->setAppId('6MMVTLW66D');
        $this->manager->setPrivateKey(file_get_contents(__DIR__ . '/prikey.pem'));
        $this->manager->setApi('http://localhost:8000/api/');
        $this->manager->setDebug(true);
    }


    public function testRunUser()
    {


        try {
            $request = new AppUserCreateRequest();
            $request->setPassword('111');
            $request->setFettle('');
            $request->setRole('admin');
            $request->setBiz(['ch','ws']);

            $biz = $this->manager->exec($request);
            if (!$biz->isSuccess()) {
                $this->fail($biz->getMessage());
            }
            $data = $biz->getData();

            //更改
            $username = $data['username'];

            $request = new AppUserUpdateRequest();
            $request->setUsername($username);
            $request->setPassword('123');
            $request->setState(false);
            $request->setRole('user');
            $request->setBiz(['ch']);

            $biz = $this->manager->exec($request);
            if (!$biz->isSuccess()) {
                $this->fail($biz->getMessage());
            }
            $data = $biz->getData();

            //print_r($data);
            //删除
            $request = new AppUserDeleteRequest();
            $request->setUsername($username);

            $biz = $this->manager->exec($request);

            $this->assertTrue($biz->isSuccess(), $biz->getMessage());

        } catch (ApiException $e) {
            $this->fail($e->getMessage());
        }
    }

}
